clc
clear

% faithful data
data = importdata('fath.txt');
[Nsamp Nk] = size(data);
data = data(:,1)';

% initial times
nint = 10;

options = zeros(1,2);
options(1) = 1000;
options(2) = 1e-6;
  
ltc = zeros(2,nint);
paratemp = cell(1,nint);
paratemp1 = paratemp;
logltemp = ltc;
for i=1:nint
 % initialize
  mixint = initsn1(data, 2);
  
  % compute MLE
  [Logl, Mix, Nit, Lld] = snmem(data, mixint, options);
  [pLogl, pMix, pNit, pLld] = plmesnmg(data, mixint, options);
  ltc(:,i) = [Logl pLogl];
  paratemp{i} = Mix;
  paratemp1{i} = pMix;
  logltemp(:,i) = [Nit pNit];
end

% resluts before 
mix0.order = 2;
mix0.mu = [1.7267 4.8026]';
mix0.lam = [5.8026 -3.4951]';
mix0.sig = [0.3801 0.6857]'.^2; %variance
mix0.pi = [0.3487 0.6513]';

[la lb] = max(ltc(1,:));
[lap lbp] = max(ltc(2,:));

[mix0.mu paratemp{lb}.mu paratemp1{lbp}.mu 
 mix0.sig paratemp{lb}.sig paratemp1{lbp}.sig 
 mix0.lam paratemp{lb}.lam paratemp1{lbp}.lam 
 mix0.pi paratemp{lb}.pi paratemp1{lbp}.pi]

[snmlog(data,mix0) snmlog(data,paratemp{lb}) snmlog(data,paratemp1{lbp})
 psnmlogg(data,mix0) psnmlogg(data,paratemp{lb}) psnmlogg(data,paratemp1{lbp})]

% figure
x = 1.5:0.01:5.3;
pdfml = snmpdf(x, paratemp{lb});
pdfpml = snmpdf(x, paratemp{lbp});
[ha hb] = hist(data,30);  
 
Ua = unique(data);
Hb = histc(data,Ua);
Hc = cumsum(Hb)./Nsamp;
cdf0 = snmcdf(x, mix0);
cdfml = snmcdf(x, paratemp{lb});
cdfpml = snmcdf(x, paratemp{lbp});

figure 
subplot(1,2,1)
b_h = bar(hb,ha./Nsamp.*8,'c');
hold on
pl2 = plot(x,pdfml,'b--');
hold on
pl3 = plot(x,pdfml,'m-.');
hold off
lgd1 = legend([pl2 pl3],'MLE','PMLE','Location','North');
set(lgd1,'Box','off');
ylabel('Density');
axis([1.5 5.2 0 0.7])
xlabel('(a)')

subplot(1,2,2)
stairs(Ua,Hc,'k-')
hold on
plot(x,cdfml,'b--');
hold on
plot(x,cdfml,'m-.');
lgd2 = legend('Empirical','MLE','PMLE','Location','NorthWest');
set(lgd2,'Box','off');
ylabel('CDF');
axis([1.5 5.2 0 1])
xlabel('(b)')

