function PLogl = psnmlog1(data, mix)
% compute penalized log-likelihood of skew normal mixtures
% Reference: Lin, T. I., Lee, J. C., & Yen, S. Y. (2007). 
% Finite mixture modelling using the skew normal distribution. 
% Statistica Sinica, 17(3), 909.
% only with our penalty p_n(\lambda)

[Nk Nd] = size(data);
plterm = - 0.05.*sum(mix.lam.^2-log(1+mix.lam.^2),1)./log(Nd);

Temp = bsxfun(@rdivide, bsxfun(@minus, data, mix.mu), sqrt(mix.sig+realmin));
Temp1 = bsxfun(@times, Temp, mix.lam);

% approximate log(\Phi(x))
Lab1 = Temp1>-30;
Lab2 = Temp1<=-30;
Tempp = Temp1;
Tempp(Lab1) = log(normcdf(Temp1(Lab1)))-realmin;
Tempp(Lab2) = -Temp1(Lab2).^2./2 + 450 + log(normcdf(-30));

%Temp2 = bsxfun(@times, normpdf(Temp).*normcdf(Temp1), mix.pi./sqrt(mix.sig));
Temp2 = bsxfun(@plus, -Temp.^2./2+Tempp, log(mix.pi+realmin)-log(mix.sig+realmin)./2);
Tempe = exp(Temp2)+realmin;
PLogl = Nd*log(2/pi)/2 + sum(log(sum(Tempe,1)),2) + plterm;



