clc
clear

% true parameters
mix0.order = 2;
mix0.mu = [-2 2]';
mix0.sig = [1 2]'; %variance
mix0.lam = [2 1]';
mix0.pi = [0.5 0.5]';
para0 = [mix0.mu' mix0.sig' mix0.lam' mix0.pi'];
Nsamp = 1000;
nint = 10;

options = zeros(1,2);
options(1) = 1000;
options(2) = 1e-6;
  
%random sample
data = randsnm(Nsamp, mix0);
Logl0 = snmlog(data, mix0);
Logl1 = psnmlogg(data, mix0);

% true values
[Logl, Mix, Nit, Lld] = snmem(data, mix0, options);
[pLogl, pMix, pNit, pLld] = plmesnmg(data, mix0, options);

ltc = zeros(2,nint);
paratemp = cell(2,nint);
logltemp = zeros(2,nint);
paraint = zeros(nint, 8);
for i=1:nint
    
 % initialize
   mixint = initsn1(data, mix0.order);
   paraint(i,:) = [mixint.mu'  mixint.sig' mixint.lam' mixint.pi'];
   
  % compute MLE and PMLE
  [Loglk, Mixk, Nitk, Lldk] = snmem(data, mixint, options);
  [pLoglk, pMixk, pNitk, pLldk] = plmesnmg(data, mixint, options);
  ltc(:,i) = [Loglk pLoglk];
  paratemp{1,i} = Mixk;
  paratemp{2,i} = pMixk;
  logltemp(:,i) = [Nitk pNitk]; 

end
  
% maxmize likelihood
[ma mb] = max(ltc,[],2);

% parameter estimation
[Mix.mu' Mix.sig' Mix.lam' Mix.pi']
[pMix.mu' pMix.sig' pMix.lam' pMix.pi']
[paratemp{1,mb(1)}.mu' paratemp{1,mb(1)}.sig' paratemp{1,mb(1)}.lam' paratemp{1,mb(1)}.pi']
[paratemp{2,mb(2)}.mu' paratemp{2,mb(2)}.sig' paratemp{2,mb(2)}.lam' paratemp{2,mb(2)}.pi']

% penalized log-likelihood
[psnmlogg(data, Mix) pLogl psnmlogg(data, paratemp{1,mb(1)}) ma(2)]

x = min(data)-1:0.1:max(data)+1;
pdfnull = snmpdf(x, mix0);
[ha hb] = hist(data,20);
pdfsn = snmpdf(x, Mix);
pdfsn1 = snmpdf(x, paratemp{1,mb(1)});


figure 
subplot(1,2,1)
l1 = bar(hb,2.*ha/Nsamp,'c');
hold on
l2 = plot(x,pdfnull,'b-');
hold on
l3 = plot(x,pdfsn,'g--');
hold on
l4 = plot(x,pdfsn1,'r-.');
hold off
lg1 = legend([l2 l3 l4],'Null settings','True values','K-means');
ylabel('Density');
axis([-4 7 0 0.32])
xlabel('(a)')

subplot(1,2,2)
plotmix(data, mix0, 'b-');
hold on
plotmix(data, Mix, 'g--');
hold on
plotmix(data, paratemp{1,mb(1)}, 'r-.');
axis([-4 7 0 0.32])
ylabel('Component Density');
xlabel('(b)')
